#
# spec file for package python-SoundCard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%if 0%{suse_version} >= 1550
%define         skip_python36 1
%endif
Name:           python-SoundCard
Version:        0.4.3
Release:        1.5
Summary:        Python package to play and record audio
License:        BSD-3-Clause
URL:            https://github.com/bastibe/SoundCard
Source0:        https://files.pythonhosted.org/packages/source/S/SoundCard/SoundCard-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/bastibe/SoundCard/master/LICENSE
Source100:      python-SoundCard-rpmlintrc
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
Requires:       python-cffi
Requires:       python-numpy
BuildArch:      noarch
%python_subpackages

%description
SoundCard is a library for playing and recording audio without
resorting to a CPython extension. Instead, it is implemented using
CFFI and the native audio libraries of Linux, Windows and macOS.

SoundCard is cross-platform, and supports Linux/pulseaudio,
Mac/coreaudio, and Windows/WASAPI. While the interface is identical
across platforms, naming schemes and block sizes can vary between
devices and platforms.

%prep
%setup -q -n SoundCard-%{version}
cp %{SOURCE1} .

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 0.4.3:
  * improves response to Pulseaudio runtime failures
  * implements named channel map elements on Linux
* Mon Aug 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.4.2:
  * adds compatibility with NixOS library naming (Thank you, shithead!)
  * fixes deprecation for Python 3.10 (Thank you, Nekyo!)
  * fixes deprecation in recent Numpy
* Wed Aug 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.4.1:
  * fixes freezing bug on Linux during startup
  * improves error reporting on Linux
  * fixes crash due to use-after-free on Linux
  * fixes unicode error on Windows
* Fri Feb 26 2021 Antonio Larrosa <alarrosa@suse.com>
- Do not build the python36 flavor on TW since numpy is a build
  dependency and it doesn't support python 3.6 anymore.
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Tue Jul 21 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.0:
  * fixes silent recordings on Windows
  * get and set the pulseaudio program name on Linux
  * fixes error with unicode soundcard names on Windows
  * adds support for pyinstaller (v4)
  * adds compatibility with Windows 7
* Mon Dec  2 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.3.3
  * Fix attribute error when accessing stream state
  * adds experimental support for exclusive mode on Windows
  * adds latency hints to the documentation
  * fix exception when monitor is default pulseaudio device
  * fixes deprecation warning
  * fixes missing dtype declaration
  * fixes sample rate conversion on macOS
  * fixes silence recording on macOS
  * makes mainloop a global singleton
  * remove useless declaration and call to _pa_stream_get_buffer_attr()
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to source release
- Update to 0.3.0:
  * Various docu updates
  * Support python 3.5
* Thu Jan  3 2019 Todd R <toddrme2178@gmail.com>
- README not needed anymore, license is in wheel
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.2.2
  * adds Sphinx/Readthedocs documentation
- Update to 0.2.1
  * adds bug fix for IPython on Windows (Thank you, Sebastian Michel!)
* Tue Nov  6 2018 Jan Engelhardt <jengelh@inai.de>
- Remove information from description that is subject to be out of
  date anytime, as well as development process instructions.
* Mon Nov  5 2018 Todd R <toddrme2178@gmail.com>
- Some wording cleanups.
* Wed Oct 31 2018 Todd R <toddrme2178@gmail.com>
- Initial version
